==> aws-java-sdk-dms-1.11.29-sources.jar: com/amazonaws/services/databasemigrationservice/model/transform/VpcSecurityGroupMembershipJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.databasemigrationservice.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.databasemigrationservice.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * VpcSecurityGroupMembership JSON Unmarshaller
 */
public class VpcSecurityGroupMembershipJsonUnmarshaller implements
        Unmarshaller<VpcSecurityGroupMembership, JsonUnmarshallerContext> {

    public VpcSecurityGroupMembership unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        VpcSecurityGroupMembership vpcSecurityGroupMembership = new VpcSecurityGroupMembership();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("VpcSecurityGroupId", targetDepth)) {
                    context.nextToken();
                    vpcSecurityGroupMembership.setVpcSecurityGroupId(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("Status", targetDepth)) {
                    context.nextToken();
                    vpcSecurityGroupMembership.setStatus(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return vpcSecurityGroupMembership;
    }

    private static VpcSecurityGroupMembershipJsonUnmarshaller instance;

    public static VpcSecurityGroupMembershipJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new VpcSecurityGroupMembershipJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-dms-1.11.45-sources.jar: com/amazonaws/services/databasemigrationservice/model/transform/VpcSecurityGroupMembershipJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.databasemigrationservice.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.databasemigrationservice.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * VpcSecurityGroupMembership JSON Unmarshaller
 */
public class VpcSecurityGroupMembershipJsonUnmarshaller implements Unmarshaller<VpcSecurityGroupMembership, JsonUnmarshallerContext> {

    public VpcSecurityGroupMembership unmarshall(JsonUnmarshallerContext context) throws Exception {
        VpcSecurityGroupMembership vpcSecurityGroupMembership = new VpcSecurityGroupMembership();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("VpcSecurityGroupId", targetDepth)) {
                    context.nextToken();
                    vpcSecurityGroupMembership.setVpcSecurityGroupId(context.getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("Status", targetDepth)) {
                    context.nextToken();
                    vpcSecurityGroupMembership.setStatus(context.getUnmarshaller(String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return vpcSecurityGroupMembership;
    }

    private static VpcSecurityGroupMembershipJsonUnmarshaller instance;

    public static VpcSecurityGroupMembershipJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new VpcSecurityGroupMembershipJsonUnmarshaller();
        return instance;
    }
}
